==> llm-docs-0.1.4.tgz: package/docs/drupal/claude-integration.md <==
---
id: drupal-claude-integration
---
# Drupal Integration Guide

<!-- title: Drupal Integration Guide -->
<!-- description: Guide for integrating Claude AI with Drupal modules in the LLM Platform Platform -->
<!-- lastUpdated: 2024-03-19 -->

## Overview

This guide covers the integration of Claude AI with Drupal modules in the LLM Platform Platform ecosystem. It details the architecture, components, and implementation patterns for AI-powered Drupal modules.

## Ecosystem Architecture

### Core Components

1. **native_aijs**
   - TypeScript AI framework
   - Unified model interface
   - vLLM and backend providers
   - Caching and observability

2. **bfllm** (LLM Inference Engine)
   - Enterprise AI deployment
   - 7B-13B model inference
   - TensorFlow.js integration
   - Agent Execution Engine
   - Federated Swarm Intelligence

3. **llm-mcp** (Model Context Protocol)
   - Central orchestration
   - Tool management
   - Bidirectional integration
   - Drupal connectivity
   - AI assistant interactions

4. **llm_platform_recipe**
   - Drupal 11 integration
   - AI Site Score
   - Vector Database
   - Progressive Assessment
   - Real-time dashboards

5. **mcp_client_extras**
   - MCP protocol extension
   - Additional tools
   - Workflow integration

## Module Architecture

### AI Swarm Intelligence

```php
// Core Components
class SwarmOrchestrator {
  public function coordinate(array $agents): void {
    // Coordinate multi-agent swarms
  }
}

class EmergenceEngine {
  public function detectBehavior(): array {
    // Detect emergent behaviors
  }
}

// Agent Types
class LlmAgent extends BaseAgent {
  public function process(array $input): array {
    // Process with language model
  }
}

class CodeGenesisAgent extends BaseAgent {
  public function generate(array $spec): array {
    // Generate code
  }
}
```

### LLM Platform

```php
// Core Services
class LlmPlatformService {
  public function process(string $input): array {
    // Process AI operations
  }
}

class LlmValidator {
  public function validate(array $input): bool {
    // Validate input
  }
}

// Integration
class LlmMcpBridge {
  public function connect(): void {
    // Connect to MCP
  }
}
```

### Migration Plus

```php
// Core Components
class MigrationRepository {
  public function getMigration(string $id): Migration {
    // Get migration
  }
}

class AiFieldMappingService {
  public function mapFields(array $source): array {
    // Map fields with AI
  }
}

// Services
class MultiModalAiOrchestrator {
  public function coordinate(array $models): void {
    // Coordinate AI models
  }
}
```

## Module Structure

### Core Modules

1. **ai_swarm_intelligence**
   - code_genesis
   - project_intelligence

2. **llm**
   - llm_ai
   - llm_ai_integration
   - llm_anthropic
   - llm_eca
   - llm_embeddings
   - llm_fleet_registry
   - llm_insights
   - llm_integrations
   - llm_local
   - llm_mcp
   - llm_mock
   - llm_openai
   - llm_openapi
   - llm_orchestration
   - llm_platform_insights
   - llm_search
   - llm_testing
   - llm_ui
   - llm_vector

3. **secure_drupal**
   - authentication
   - compliance
   - compliance_framework
   - openapi_compliance_enforcer
   - password-policy
   - policy_bridge
   - release_evidence
   - resources
   - secure_accessibility
   - secure_ai_compliance
   - secure_audit
   - secure_auth
   - secure_compliance
   - secure_compliance_profile
   - secure_config
   - secure_controls
   - secure_core
   - secure_drupal_healing_logging
   - secure_eca
   - secure_evidence_config
   - secure_evidence_dblog
   - secure_evidence_log
   - secure_fedramp
   - secure_headers
   - secure_pci
   - secure_zero_trust
   - separation_of_duties
   - theme_security

### Integration Modules

1. **mcp_client_extras**
   - mcp_ai_platform
   - mcp_analytics_pro
   - mcp_integration_hub
   - mcp_workflow_engine

2. **langchain**
   - langchain_ai
   - langchain_eca
   - langfuse_observability
   - langgraph
   - llm_adapter
   - llm_insights

## Implementation Guide

### Installation

```bash
# Install module
drush en <module_name>

# Install with dependencies
composer require bluefly/<module_name>
drush en <module_name>

# Install LLM platform
composer require drupal/llm
drush recipe:apply llm_platform

# Production configuration
drush llm:configure --environment=production
```

### Testing

```bash
# Run all tests
cd <module_directory>
composer test

# Specific test suites
composer test-unit
composer test-kernel
```

### Development

1. **Module Setup**
   ```php
   // mymodule.info.yml
   name: My AI Module
   type: module
   core_version_requirement: ^11
   dependencies:
     - llm:llm_ai
     - llm:llm_mcp
   ```

2. **Service Definition**
   ```php
   // mymodule.services.yml
   services:
     mymodule.ai_service:
       class: Drupal\mymodule\AiService
       arguments: ['@llm.platform', '@llm.validator']
   ```

3. **Controller Implementation**
   ```php
   // src/Controller/AiController.php
   class AiController extends ControllerBase {
     public function process() {
       // Process AI request
     }
   }
   ```

## Security Framework

1. **Authentication**
   - Role-based access
   - API key management
   - Input validation
   - Rate limiting

2. **Compliance**
   - OpenAPI compliance
   - FedRAMP support
   - PCI compliance
   - Zero trust

3. **Audit**
   - Comprehensive logging
   - Evidence collection
   - Security headers
   - Access control

## Related Documentation

- [Development Guide](../development/README)
- [Security Guide](../operations/security)
- [Testing Guide](../testing/README)
- [CI/CD Guide](../development/pipeline)
- [Monitoring Guide](../operations/monitoring)

==> llm-docs-1.0.1.tgz: package/docs/drupal/claude-integration.md <==
---
id: drupal-claude-integration
---
# Drupal Integration Guide

<!-- title: Drupal Integration Guide -->
<!-- description: Guide for integrating Claude AI with Drupal modules in the Bluefly Platform -->
<!-- lastUpdated: 2024-03-19 -->

## Overview

This guide covers the integration of Claude AI with Drupal modules in the Bluefly Platform ecosystem. It details the architecture, components, and implementation patterns for AI-powered Drupal modules.

## Ecosystem Architecture

### Core Components

1. **native_aijs**
   - TypeScript AI framework
   - Unified model interface
   - vLLM and backend providers
   - Caching and observability

2. **bfllm** (LLM Inference Engine)
   - Enterprise AI deployment
   - 7B-13B model inference
   - TensorFlow.js integration
   - Agent Execution Engine
   - Federated Swarm Intelligence

3. **bfmcp** (Model Context Protocol)
   - Central orchestration
   - Tool management
   - Bidirectional integration
   - Drupal connectivity
   - AI assistant interactions

4. **llm_platform_recipe**
   - Drupal 11 integration
   - AI Site Score
   - Vector Database
   - Progressive Assessment
   - Real-time dashboards

5. **mcp_client_extras**
   - MCP protocol extension
   - Additional tools
   - Workflow integration

## Module Architecture

### AI Swarm Intelligence

```php
// Core Components
class SwarmOrchestrator {
  public function coordinate(array $agents): void {
    // Coordinate multi-agent swarms
  }
}

class EmergenceEngine {
  public function detectBehavior(): array {
    // Detect emergent behaviors
  }
}

// Agent Types
class LlmAgent extends BaseAgent {
  public function process(array $input): array {
    // Process with language model
  }
}

class CodeGenesisAgent extends BaseAgent {
  public function generate(array $spec): array {
    // Generate code
  }
}
```

### LLM Platform

```php
// Core Services
class LlmPlatformService {
  public function process(string $input): array {
    // Process AI operations
  }
}

class LlmValidator {
  public function validate(array $input): bool {
    // Validate input
  }
}

// Integration
class LlmMcpBridge {
  public function connect(): void {
    // Connect to MCP
  }
}
```

### Migration Plus

```php
// Core Components
class MigrationRepository {
  public function getMigration(string $id): Migration {
    // Get migration
  }
}

class AiFieldMappingService {
  public function mapFields(array $source): array {
    // Map fields with AI
  }
}

// Services
class MultiModalAiOrchestrator {
  public function coordinate(array $models): void {
    // Coordinate AI models
  }
}
```

## Module Structure

### Core Modules

1. **ai_swarm_intelligence**
   - code_genesis
   - project_intelligence

2. **llm**
   - llm_ai
   - llm_ai_integration
   - llm_anthropic
   - llm_eca
   - llm_embeddings
   - llm_fleet_registry
   - llm_insights
   - llm_integrations
   - llm_local
   - llm_mcp
   - llm_mock
   - llm_openai
   - llm_openapi
   - llm_orchestration
   - llm_platform_insights
   - llm_search
   - llm_testing
   - llm_ui
   - llm_vector

3. **secure_drupal**
   - authentication
   - compliance
   - compliance_framework
   - openapi_compliance_enforcer
   - password-policy
   - policy_bridge
   - release_evidence
   - resources
   - secure_accessibility
   - secure_ai_compliance
   - secure_audit
   - secure_auth
   - secure_compliance
   - secure_compliance_profile
   - secure_config
   - secure_controls
   - secure_core
   - secure_drupal_healing_logging
   - secure_eca
   - secure_evidence_config
   - secure_evidence_dblog
   - secure_evidence_log
   - secure_fedramp
   - secure_headers
   - secure_pci
   - secure_zero_trust
   - separation_of_duties
   - theme_security

### Integration Modules

1. **mcp_client_extras**
   - mcp_ai_platform
   - mcp_analytics_pro
   - mcp_integration_hub
   - mcp_workflow_engine

2. **langchain**
   - langchain_ai
   - langchain_eca
   - langfuse_observability
   - langgraph
   - llm_adapter
   - llm_insights

## Implementation Guide

### Installation

```bash
# Install module
drush en <module_name>

# Install with dependencies
composer require bluefly/<module_name>
drush en <module_name>

# Install LLM platform
composer require drupal/llm
drush recipe:apply llm_platform

# Production configuration
drush llm:configure --environment=production
```

### Testing

```bash
# Run all tests
cd <module_directory>
composer test

# Specific test suites
composer test-unit
composer test-kernel
```

### Development

1. **Module Setup**
   ```php
   // mymodule.info.yml
   name: My AI Module
   type: module
   core_version_requirement: ^11
   dependencies:
     - llm:llm_ai
     - llm:llm_mcp
   ```

2. **Service Definition**
   ```php
   // mymodule.services.yml
   services:
     mymodule.ai_service:
       class: Drupal\mymodule\AiService
       arguments: ['@llm.platform', '@llm.validator']
   ```

3. **Controller Implementation**
   ```php
   // src/Controller/AiController.php
   class AiController extends ControllerBase {
     public function process() {
       // Process AI request
     }
   }
   ```

## Security Framework

1. **Authentication**
   - Role-based access
   - API key management
   - Input validation
   - Rate limiting

2. **Compliance**
   - OpenAPI compliance
   - FedRAMP support
   - PCI compliance
   - Zero trust

3. **Audit**
   - Comprehensive logging
   - Evidence collection
   - Security headers
   - Access control

## Related Documentation

- [Development Guide](../development/README)
- [Security Guide](../operations/security)
- [Testing Guide](../testing/README)
- [CI/CD Guide](../development/pipeline)
- [Monitoring Guide](../operations/monitoring)
